label nCells = mesh.nCells(); //Number of cells
simpleMatrix<scalar> CoeffMat(nCells); //Coefficient matrix

// Initialization of matrix
for(label i = 0; i < nCells; i++)
{
    CoeffMat.source()[i] = 0.0;
    for(label j = 0; j < nCells; j++)
    {
        CoeffMat[i][j] = 0.0;
    }
}

// Assigning diagonal coefficients and source term
for(label i = 0; i < nCells; ++i)
{
    CoeffMat[i][i] = diag[i];
    CoeffMat.source()[i] = source[i][0];
}

// Assigning off-diagonal coefficients
for(label faceI = 0; faceI < lAdd.size(); ++faceI)
{
    label l = lAdd[faceI];
    label u = uAdd[faceI];
    CoeffMat[l][u] = upper[faceI];
    CoeffMat[u][l] = lower[faceI];
}

Info << "=== Matrix CoeffMat before adding contribution of BCs ==="<< endl;
for(label i = 0; i < nCells; ++i)
{
    for(label j = 0; j < nCells; ++j)
    {
        Info << CoeffMat[i][j] << " ";
    }
    Info << CoeffMat.source()[i] << endl;
}
Info << endl;

// Assigning contribution from BC
forAll(U.boundaryField(), patchI)
{
    const fvPatch &pp = U.boundaryField()[patchI].patch();
    forAll(pp, faceI)
    {
        label cellI = pp.faceCells()[faceI];
        CoeffMat[cellI][cellI] += UEqnWithPressure.internalCoeffs()[patchI][faceI][0];
        CoeffMat.source()[cellI] += UEqnWithPressure.boundaryCoeffs()[patchI][faceI][0];
    }
}

Info << "=== Matrix CoeffMat after adding contribution of BCs ==="<< endl;
for(label i = 0; i < nCells; ++i)
{
    for(label j = 0; j < nCells; ++j)
    {
        Info << CoeffMat[i][j] << " ";
    }
    Info << CoeffMat.source()[i] << endl;
}
Info << endl;

// Solving the full linear system
scalarField Ux(CoeffMat.solve());

Info << "=== Results ==="<< endl;
for(label i = 0; i < nCells; ++i)
{
    Info << "Cell" << i << ": Ux_1="
    << U.internalField()[i].component(0)
    << ", Ux_2=" << Ux[i] << endl;
}
Info << endl;
